#!/usr/bin/env python
# -*- coding: utf-8 -*-
from __future__ import unicode_literals, division, absolute_import, print_function
import os, os.path, sys
import subprocess
from subprocess import Popen, PIPE
from os.path import expanduser

PY2 = sys.version_info[0] == 2
if PY2:
    import codecs
    file_open = codecs.open
    import Tkinter as tkinter
    import tkFileDialog as tkinter_filedialog
else:
    file_open = open
    import tkinter
    import tkinter.filedialog as tkinter_filedialog

# display epub file selection dialog
def GetFileName(initialdir):
    root = tkinter.Tk()
    root.withdraw()
    filetypes = (('OpenDocument files', '*.odt'),("All files", "*.*"))
    file_path = tkinter_filedialog.askopenfilename(initialdir = initialdir, filetypes = filetypes, title='Select .odt file')
    return file_path

# simple Java wrapper
def w2lWrapper(*args):
    process = Popen(list(args), stdout=PIPE, stderr=PIPE)
    ret = process.communicate()
    return ret

# main routine
def run(bk):
    odt_file = None
    
    # get document folder preference
    prefs = bk.getPrefs()
    if 'initialdir' in prefs:
        initialdir = prefs['initialdir']
    else:
        initialdir = expanduser('~')

    # get ODT file namee
    odt_file = GetFileName(initialdir)

    # save document folder as preference
    if not 'initialdir' in prefs and initialdir:
        prefs['initialdir'] = os.path.dirname(odt_file)
        bk.savePrefs(prefs)
        
    # process ODT file
    if odt_file:
        # get the writer2latex Java binary and config file paths
        w2l_path = os.path.join(os.path.join(bk._w.plugin_dir, 'ODTImport'), 'writer2latex.jar')
        w2l_config_path = os.path.join(os.path.join(bk._w.plugin_dir, 'ODTImport'), 'config.xml')
        w2l_css_path = os.path.join(os.path.join(bk._w.plugin_dir, 'ODTImport'), 'epub.css')

        
        # define command line arguments
        if os.path.isfile(w2l_config_path) and os.path.isfile(w2l_css_path):
            args = ['java', '-jar', w2l_path, '-epub', '-config=' + w2l_config_path, '-stylesheet=' + w2l_css_path, odt_file] 
        elif os.path.isfile(w2l_config_path) and not os.path.isfile(w2l_css_path):
            args = ['java', '-jar', w2l_path, '-epub', '-config=' + w2l_config_path, odt_file]
        elif not os.path.isfile(w2l_config_path) and os.path.isfile(w2l_css_path):
            args = ['java', '-jar', w2l_path, '-epub', '-stylesheet=' + w2l_css_path, odt_file] 
        else:
            args = ['java', '-jar', w2l_path, '-epub', odt_file]
        result = w2lWrapper(*args)
        epub_path = os.path.splitext(odt_file)[0] + '.epub'

        # import epub into Sigil
        if os.path.isfile(epub_path):
            with file_open(epub_path,'rb')as fp:
                data = fp.read()
            bk.addotherfile('dummy.epub', data)
            os.remove(epub_path)
            return 0
        else:
            w2l_warnings = result[0].decode('utf-8', 'ignore').splitlines()
            for line in w2l_warnings:
                print(line) 
            return -1

def main():
    print('I reached main when I should not have\n')
    return -1

if __name__ == "__main__":
    sys.exit(main())
